@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2012-2017 Marc Ferland
+# Copyright (C) 2012-2018 Marc Ferland
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,8 +16,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 OPTIONS="\
---style=kr \
+--style=linux \
 --pad-oper \
+--indent=force-tab=8 \
+--max-code-length=80 \
 -k3 \
 -W3 \
 -m0 \
